pub fn reset()Expand description
Clear the global log. Used by the (future) in-TUI “clear logs” action and by tests that need a clean slate.
pub fn reset()Clear the global log. Used by the (future) in-TUI “clear logs” action and by tests that need a clean slate.