create_pr

Function create_pr 

pub fn create_pr(req: &PrCreateRequest<'_>) -> Result<CreatedPr>
Shell out to gh pr create with a body file already rendered by crate::pr_templates::render_pr_body. Parses the URL printed by gh on success to extract the PR number.