pub fn fetch_remote_milestones(slug: &str) -> Result<Vec<RemoteMilestone>>Expand description
Run gh api repos/<slug>/milestones?state=all and parse the
result. Returns an empty vec when the remote has no milestones.
pub fn fetch_remote_milestones(slug: &str) -> Result<Vec<RemoteMilestone>>Run gh api repos/<slug>/milestones?state=all and parse the
result. Returns an empty vec when the remote has no milestones.