pub struct RemoteLabel {
pub name: String,
pub description: Option<String>,
pub color: String,
}Expand description
One label as returned by gh label list --json … for the upstream
remote. Colour is normalised to lowercase 6-hex on parse so the
diff doesn’t surface a spurious “update” when GitHub renders it
uppercase.
Fields
name: Stringdescription: Option<String>color: StringTrait Implementations
Sourceimpl Clone for RemoteLabel
impl Clone for RemoteLabel
Sourcefn clone(&self) -> RemoteLabel
fn clone(&self) -> RemoteLabel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteLabel
impl Debug for RemoteLabel
impl Eq for RemoteLabel
Sourceimpl PartialEq for RemoteLabel
impl PartialEq for RemoteLabel
Sourcefn eq(&self, other: &RemoteLabel) -> bool
fn eq(&self, other: &RemoteLabel) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemoteLabel